//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[YakuSerializer](index.md)/[YakuSerializer](-yaku-serializer.md)

# YakuSerializer

[common]\
constructor(yakus: [Yakus](../-yakus/index.md))
